==> ws-addressing4agreement-0.9.2-sources.jar: com/ebmwebsourcing/addressing/addressing4agreement/monitoring/impl/EndpointReferenceTypeImpl.java <==
/**
 * easyWSDL - easyWSDL toolbox Platform.
 * Copyright (c) 2008,  eBM Websourcing
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.ebmwebsourcing.addressing.addressing4agreement.monitoring.impl;

import org.ow2.easywsdl.schema.api.abstractElmt.AbstractSchemaElementImpl;

import com.ebmwebsourcing.addressing.addressing4agreement.monitoring.api.EndpointReferenceType;
import com.ebmwebsourcing.addressing.addressing4agreement.monitoring.api.ReferenceParametersType;
import com.ebmwebsourcing.wsstar.addressing.definition.api.WSAddressingException;
import com.ebmwebsourcing.wsstar.addressing.definition.api.absitf.AbsItfEndpointReferenceType;
import com.ebmwebsourcing.wsstar.addressing.definition.api.absitf.AbsItfReferenceParametersType;
import com.ebmwebsourcing.wsstar.addressing.definition.decorator.DecoratorEndpointReferenceTypeImpl;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@SuppressWarnings("unchecked")
public class EndpointReferenceTypeImpl extends
DecoratorEndpointReferenceTypeImpl<ReferenceParametersType> implements
EndpointReferenceType {

	/**
	 *
	 */
	private static final long serialVersionUID = 1L;

	private ReferenceParametersType ref;


	@SuppressWarnings("unchecked")
	public EndpointReferenceTypeImpl(AbsItfEndpointReferenceType epr) throws WSAddressingException {
		super(epr);
		if (epr.getReferenceParameters() != null)
			this.ref = new ReferenceParametersTypeImpl(epr.getReferenceParameters());
	}


	@Override
	public ReferenceParametersType getReferenceParameters()
	throws WSAddressingException {
		return this.ref;
	}


	@Override
	public void setReferenceParameters(ReferenceParametersType ref) {
		((com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.EndpointReferenceType)this.model).setReferenceParameters((com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.ReferenceParametersType) ((AbstractSchemaElementImpl)ref).getModel());
		this.ref = ref;
	}


	public ReferenceParametersType newReferenceParameters()
	throws WSAddressingException {
		return new ReferenceParametersTypeImpl(new com.ebmwebsourcing.wsstar.addressing.definition.impl.ReferenceParametersTypeImpl(new com.ebmwebsourcing.wsstar.addressing.definition.org.w3._2005._08.addressing.ReferenceParametersType(), this));
	}


}

==> ws-addressing4agreement-1.2-sources.jar: com/ebmwebsourcing/addressing/addressing4agreement/monitoring/impl/EndpointReferenceTypeImpl.java <==
/**
 * easyWSDL - easyWSDL toolbox Platform.
 * Copyright (c) 2008,  eBM Websourcing
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the University of California, Berkeley nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.ebmwebsourcing.addressing.addressing4agreement.monitoring.impl;

import org.ow2.easywsdl.schema.api.abstractElmt.AbstractSchemaElementImpl;

import com.ebmwebsourcing.addressing.addressing4agreement.monitoring.api.EndpointReferenceType;
import com.ebmwebsourcing.addressing.addressing4agreement.monitoring.api.ReferenceParametersType;
import com.ebmwebsourcing.wsstar.addressing.definition.api.WSAddressingException;
import com.ebmwebsourcing.wsstar.addressing.definition.api.absitf.AbsItfEndpointReferenceType;
import com.ebmwebsourcing.wsstar.addressing.definition.api.absitf.AbsItfReferenceParametersType;
import com.ebmwebsourcing.wsstar.addressing.definition.decorator.DecoratorEndpointReferenceTypeImpl;


/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@SuppressWarnings("unchecked")
public class EndpointReferenceTypeImpl extends
DecoratorEndpointReferenceTypeImpl<ReferenceParametersType> implements
EndpointReferenceType {

	/**
	 *
	 */
	private static final long serialVersionUID = 1L;

	private ReferenceParametersType ref;


	@SuppressWarnings("unchecked")
	public EndpointReferenceTypeImpl(AbsItfEndpointReferenceType epr) throws WSAddressingException {
		super(epr);
		if (epr.getReferenceParameters() != null)
			this.ref = new ReferenceParametersTypeImpl(epr.getReferenceParameters());
	}


	@Override
	public ReferenceParametersType getReferenceParameters()
	throws WSAddressingException {
		return this.ref;
	}


	@Override
	public void setReferenceParameters(ReferenceParametersType ref) {
		((com.ebmwebsourcing.wsstar.jaxb.addressing.EndpointReferenceType)this.model).setReferenceParameters((com.ebmwebsourcing.wsstar.jaxb.addressing.ReferenceParametersType) ((AbstractSchemaElementImpl)ref).getModel());
		this.ref = ref;
	}


	public ReferenceParametersType newReferenceParameters()
	throws WSAddressingException {
		return new ReferenceParametersTypeImpl(new com.ebmwebsourcing.wsstar.addressing.definition.impl.ReferenceParametersTypeImpl(new com.ebmwebsourcing.wsstar.jaxb.addressing.ReferenceParametersType(), this));
	}


}
